==> vtours-computop-payment-service-sdk-0.7.1-013033.zip: src/Mapper/CreditCard/Recurring/CreditCardMapperRecurring.php <==
<?php
/**
 *  LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 *  and is private by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license
 *  is a violation of the license agreement and will be prosecuted by
 *  civil and criminal law.
 *
 * @copyright 2021 Lifestyle Webconsulting GmbH
 * @link http://www.life-style.de
 */

namespace Vtours\ComputopPaymentSdk\Mapper\CreditCard\Recurring;

use Psr\Http\Message\ResponseInterface as HttpResponseInterface;
use Vtours\ComputopPaymentSdk\Exception\ComputopPaymentServiceException;
use Vtours\ComputopPaymentSdk\Mapper\ResponseMapperAbstract;
use Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring\InnerResponse;
use Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring\Request;
use Vtours\ComputopPaymentSdk\Model\PaymentServiceResponse;
use Vtours\ComputopPaymentSdk\Model\RequestInterface as RequestModelInterface;
use Vtours\ComputopPaymentSdk\Model\ResponseInterface as ResponseModelInterface;

/**
 * Class CreditCardMapperRecurring
 * @package Vtours\ComputopPaymentSdk\Mapper\CreditCard
 */
class CreditCardMapperRecurring extends ResponseMapperAbstract
{
    /**
     * @param HttpResponseInterface $response
     * @return PaymentServiceResponse
     * @throws ComputopPaymentServiceException
     */
    public function map(HttpResponseInterface $response): PaymentServiceResponse
    {
        $responseBody = $this->getResponseBody($response);

        return (new PaymentServiceResponse())
            ->setStatus($responseBody['status'])
            ->setStatusCode($responseBody['status_code'])
            ->setMessage($responseBody['message'])
            ->setRequest($this->mapRequest($response))
            ->setResponse($this->mapResponse($response));
    }

    /**
     * @param HttpResponseInterface $response
     * @return RequestModelInterface
     */
    protected function mapRequest(HttpResponseInterface $response): RequestModelInterface
    {
        $responseBody = $this->getResponseBody($response);

        return (new Request())
            ->setAmount($responseBody['request_data']['amount'] ?? null)
            ->setCurrency($responseBody['request_data']['currency'] ?? null)
            ->setReferenceNumber($responseBody['request_data']['reference_number'] ?? '')
            ->setTransactionId($responseBody['request_data']['transaction_id'] ?? null)
            ->setOrderDescription($responseBody['request_data']['order_description'] ?? null)
            ->setAccountOwner($responseBody['request_data']['account_owner'] ?? null)
            ->setAddressCountry($responseBody['request_data']['address_country'] ?? null)
            ->setCardNumber($responseBody['request_data']['card_number'] ?? null)
            ->setCardBrand($responseBody['request_data']['card_brand'] ?? null)
            ->setCardExpiryDate($responseBody['request_data']['card_expiry_date'] ?? null)
            ->setCardHolderName($responseBody['request_data']['card_holder_name'] ?? null)
            ->setCardHolderCountry($responseBody['request_data']['card_holder_country'] ?? null)
            ->setCardHolderCity($responseBody['request_data']['card_holder_city'] ?? null)
            ->setSchemeReferenceId($responseBody['request_data']['scheme_reference_id'] ?? null);
    }

    /**
     * @param HttpResponseInterface $response
     * @return InnerResponse
     * @throws ComputopPaymentServiceException
     */
    protected function mapResponse(HttpResponseInterface $response): ResponseModelInterface
    {
        $responseBody = $this->getResponseBody($response);

        if (empty($responseBody['response_data'])) {
            throw ComputopPaymentServiceException::withMissingResponseData($response);
        }

        $responseData = array_change_key_case($responseBody['response_data'], CASE_LOWER);

        return (new InnerResponse())
            ->setMid($responseData['mid'] ?? null)
            ->setPaymentId($responseData['payid'] ?? null)
            ->setXid($responseData['xid'] ?? null)
            ->setTransactionId($responseData['transid'] ?? null)
            ->setReferenceNumber($responseData['refnr'] ?? null)
            ->setCard($responseData['card'] ?? null)
            ->setCode($responseData['code'] ?? null)
            ->setStatus($responseData['status'] ?? null)
            ->setDescription($responseData['description'] ?? null);
    }
}

==> vtours-computop-payment-service-sdk-0.7.2-a7635a.zip: src/Mapper/CreditCard/Recurring/CreditCardMapperRecurring.php <==
<?php
/**
 *  LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 *  and is private by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license
 *  is a violation of the license agreement and will be prosecuted by
 *  civil and criminal law.
 *
 * @copyright 2021 Lifestyle Webconsulting GmbH
 * @link http://www.life-style.de
 */

namespace Vtours\ComputopPaymentSdk\Mapper\CreditCard\Recurring;

use Psr\Http\Message\ResponseInterface as HttpResponseInterface;
use Vtours\ComputopPaymentSdk\Exception\ComputopPaymentServiceException;
use Vtours\ComputopPaymentSdk\Mapper\ResponseMapperAbstract;
use Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring\InnerResponse;
use Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring\Request;
use Vtours\ComputopPaymentSdk\Model\PaymentServiceResponse;
use Vtours\ComputopPaymentSdk\Model\RequestInterface as RequestModelInterface;
use Vtours\ComputopPaymentSdk\Model\ResponseInterface as ResponseModelInterface;

/**
 * Class CreditCardMapperRecurring
 * @package Vtours\ComputopPaymentSdk\Mapper\CreditCard
 */
class CreditCardMapperRecurring extends ResponseMapperAbstract
{
    /**
     * @param HttpResponseInterface $response
     * @return PaymentServiceResponse
     * @throws ComputopPaymentServiceException
     */
    public function map(HttpResponseInterface $response): PaymentServiceResponse
    {
        $responseBody = $this->getResponseBody($response);

        return (new PaymentServiceResponse())
            ->setStatus($responseBody['status'])
            ->setStatusCode($responseBody['status_code'])
            ->setMessage($responseBody['message'])
            ->setRequest($this->mapRequest($response))
            ->setResponse($this->mapResponse($response));
    }

    /**
     * @param HttpResponseInterface $response
     * @return RequestModelInterface
     */
    protected function mapRequest(HttpResponseInterface $response): RequestModelInterface
    {
        $responseBody = $this->getResponseBody($response);

        return (new Request())
            ->setAmount($responseBody['request_data']['amount'] ?? null)
            ->setCurrency($responseBody['request_data']['currency'] ?? null)
            ->setReferenceNumber($responseBody['request_data']['reference_number'] ?? '')
            ->setTransactionId($responseBody['request_data']['transaction_id'] ?? null)
            ->setOrderDescription($responseBody['request_data']['order_description'] ?? null)
            ->setAccountOwner($responseBody['request_data']['account_owner'] ?? null)
            ->setAddressCountry($responseBody['request_data']['address_country'] ?? null)
            ->setCardNumber($responseBody['request_data']['card_number'] ?? null)
            ->setCardBrand($responseBody['request_data']['card_brand'] ?? null)
            ->setCardExpiryDate($responseBody['request_data']['card_expiry_date'] ?? null)
            ->setCardHolderName($responseBody['request_data']['card_holder_name'] ?? null)
            ->setCardHolderCountry($responseBody['request_data']['card_holder_country'] ?? null)
            ->setCardHolderCity($responseBody['request_data']['card_holder_city'] ?? null)
            ->setSchemeReferenceId($responseBody['request_data']['scheme_reference_id'] ?? null);
    }

    /**
     * @param HttpResponseInterface $response
     * @return InnerResponse
     * @throws ComputopPaymentServiceException
     */
    protected function mapResponse(HttpResponseInterface $response): ResponseModelInterface
    {
        $responseBody = $this->getResponseBody($response);

        if (empty($responseBody['response_data'])) {
            throw ComputopPaymentServiceException::withMissingResponseData($response);
        }

        $responseData = array_change_key_case($responseBody['response_data'], CASE_LOWER);

        return (new InnerResponse())
            ->setMid($responseData['mid'] ?? null)
            ->setPaymentId($responseData['payid'] ?? null)
            ->setXid($responseData['xid'] ?? null)
            ->setTransactionId($responseData['transid'] ?? null)
            ->setReferenceNumber($responseData['refnr'] ?? null)
            ->setCard($responseData['card'] ?? null)
            ->setCode($responseData['code'] ?? null)
            ->setStatus($responseData['status'] ?? null)
            ->setDescription($responseData['description'] ?? null)
            ->setSchemeReferenceId($responseData['schemereferenceid'] ?? null);
    }
}
